![](https://img.shields.io/badge/pypi-2.9.2-purple) ![](https://img.shields.io/badge/python-%203.8%20%7C%203.8%20%7C%203.9%20%7C%203.10-red) ![](https://img.shields.io/badge/OSI-%20Approved-terquise)

# How to install
No requirments other than the standard library
`pip install kittyscript`(For the latest version)

`pip install Kittyscript==version number`(For specific version)

[PyPi for Package History](http://pypi.org/project/Kittyscript/2.9.4/#history "PyPi for Package History") |  [Github](http://github.com/Iwertyuiop123653/kitty-script- "Github")  | [Wiki](https://slimwiki.com/kittyscript "Wiki") | [Help with kittyscript](https://forms.gle/PhFYUYUN5wRLVyFZ9 "Help with kittyscript") | [forum](https://www.reddit.com/r/kittyscript/ "forum")

# How To use
**To print text type say() How does it work its just like print in python**

**How to generate a random number generatenumber()**

_Note: Now generatenumber will have parameters like generatenumber(200, 1000)_

**addnum() is used to add two numbers together like this addnum(10, 20) The answer would be 30**

**addfloat() is the exact same but with floats**

**divide() divides two numbers**

**version() shows the current version**

**CreateFile() has 2 perimeters CreateFile(Nameoffile.something, Content of file)**

_Short description: Cerates a file with text in it_

**hashshaw256() create a hash by hashshaw256(putting the text you want to hash here)**

_Short description: create hashes_

**curtime() shows current time**